"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.LanguageContextProvider = exports.LanguageContext = void 0;

var _react = _interopRequireWildcard(require("react"));

var RNLocalize = _interopRequireWildcard(require("react-native-localize"));

var _i18nJs = _interopRequireDefault(require("i18n-js"));

var _lodash = _interopRequireDefault(require("lodash.memoize"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const LanguageContext = (0, _react.createContext)({});
exports.LanguageContext = LanguageContext;

const LanguageContextProvider = ({
  children,
  translationGetters,
  currentLanguage
}) => {
  const [selected, setSelected] = (0, _react.useState)('en');
  (0, _react.useEffect)(() => {
    setSelected(currentLanguage);
  }, []);
  const translate = (0, _lodash.default)((key, config) => _i18nJs.default.t(key, config), (key, config) => config ? key + JSON.stringify(config) : key);

  const setI18nConfig = () => {
    const fallback = {
      languageTag: selected
    };
    const {
      languageTag
    } = // RNLocalize.findBestAvailableLanguage(Object.keys(translationGetters)) ||
    fallback;
    translate.cache.clear();
    _i18nJs.default.translations = {
      [languageTag]: translationGetters[languageTag]()
    };
    _i18nJs.default.locale = languageTag;
  };

  setI18nConfig();

  const handleLocalizationChange = () => {
    setI18nConfig();
  };

  (0, _react.useEffect)(() => {
    RNLocalize.addEventListener('change', handleLocalizationChange);
    return RNLocalize.removeEventListener('change', handleLocalizationChange);
  }, [selected]);

  const translateText = val => {
    if (val === '' || val === null) {
      return '';
    } else {
      if (selected === 'en') {
        return val;
      } // console.log(
      //   'test translation errors ',
      //   translate(val),
      //   translate(val).startsWith(`[missing "${selected}.`)
      // );


      if (translate(val).startsWith("[missing \"".concat(selected, "."))) {
        return val;
      }

      return translate(val);
    }
  };

  return /*#__PURE__*/_react.default.createElement(LanguageContext.Provider, {
    value: {
      current: {
        selected,
        setSelected,
        translate,
        translateText
      }
    }
  }, children);
};

exports.LanguageContextProvider = LanguageContextProvider;

const useLanguage = () => {
  const context = (0, _react.useContext)(LanguageContext);
  return context === null || context === void 0 ? void 0 : context.current;
};

var _default = useLanguage;
exports.default = _default;
//# sourceMappingURL=LanguageService.js.map