import React, { createContext, useEffect, useState, useContext } from 'react';
import * as RNLocalize from 'react-native-localize';
import i18n from 'i18n-js';
import memoize from 'lodash.memoize';
export const LanguageContext = createContext({});
export const LanguageContextProvider = ({
  children,
  translationGetters,
  currentLanguage
}) => {
  const [selected, setSelected] = useState('en');
  useEffect(() => {
    setSelected(currentLanguage);
  }, []);
  const translate = memoize((key, config) => i18n.t(key, config), (key, config) => config ? key + JSON.stringify(config) : key);

  const setI18nConfig = () => {
    const fallback = {
      languageTag: selected
    };
    const {
      languageTag
    } = // RNLocalize.findBestAvailableLanguage(Object.keys(translationGetters)) ||
    fallback;
    translate.cache.clear();
    i18n.translations = {
      [languageTag]: translationGetters[languageTag]()
    };
    i18n.locale = languageTag;
  };

  setI18nConfig();

  const handleLocalizationChange = () => {
    setI18nConfig();
  };

  useEffect(() => {
    RNLocalize.addEventListener('change', handleLocalizationChange);
    return RNLocalize.removeEventListener('change', handleLocalizationChange);
  }, [selected]);

  const translateText = val => {
    if (val === '' || val === null) {
      return '';
    } else {
      if (selected === 'en') {
        return val;
      } // console.log(
      //   'test translation errors ',
      //   translate(val),
      //   translate(val).startsWith(`[missing "${selected}.`)
      // );


      if (translate(val).startsWith("[missing \"".concat(selected, "."))) {
        return val;
      }

      return translate(val);
    }
  };

  return /*#__PURE__*/React.createElement(LanguageContext.Provider, {
    value: {
      current: {
        selected,
        setSelected,
        translate,
        translateText
      }
    }
  }, children);
};

const useLanguage = () => {
  const context = useContext(LanguageContext);
  return context === null || context === void 0 ? void 0 : context.current;
};

export default useLanguage;
//# sourceMappingURL=LanguageService.js.map