import React, { FC, ReactNode } from 'react';
import { Text as TextX, TextProps as TextPropsX } from 'react-native';
import useLanguage from '../../services/LanguageService';

export type TextProps = TextPropsX & {
  children: ReactNode | string;
  translationType?: 'default' | 'id' | 'none';
};
export const Text: FC<TextProps> = (props: TextProps) => {
  const { children, translationType } = props;
  const PropsX = props;
  delete PropsX.children;
  delete PropsX.translationType;
  const translateText = useLanguage()?.translateText;
  const translate = useLanguage()?.translate;
  switch (translationType) {
    case 'none':
      return <TextX {...PropsX}>{children}</TextX>;
    case 'id':
      return (
        <TextX {...PropsX}>
          {translate ? translate(children as string) : children}
        </TextX>
      );
    case 'default':
      return (
        <TextX {...PropsX}>
          {translateText ? translateText(children as string) : children}
        </TextX>
      );
    default:
      return (
        <TextX {...PropsX}>
          {translateText ? translateText(children as string) : children}
        </TextX>
      );
  }
};
