import React, { FC } from 'react';
import {
  Textarea as TextareaX,
  Item,
  NativeBase,
  RnViewStyleProp,
} from 'native-base';
import { styles } from './styles';
import {
  borderedInputVariables,
  primaryInputVariables,
} from '../../Configurations/ThemeConfig';
import { Label } from '../Label/Label';
import useLanguage from '../../services/LanguageService';

type Props = NativeBase.Textarea & {
  type?: 'material' | 'material-black' | 'primary' | 'bordered';
  TextareaStyle?: any;
  label?: string;
  style?: RnViewStyleProp;
  labelProps?: NativeBase.Label;
  TextareaProps?: NativeBase.Textarea;
  shadow?: boolean;
  // children: ReactNode;
};
export const Textarea: FC<Props> = (props: Props) => {
  const { type, label, labelProps, style, TextareaStyle, shadow } = props;
  const propsX = { ...props };
  propsX.style = TextareaStyle;
  delete propsX.labelProps;
  delete propsX.type;
  delete propsX.label;
  delete propsX.TextareaStyle;

  const translateText = useLanguage().translateText;
  const renderElement = (
    inputStyleX?: any,
    labelStyle?: any,
    placeholderTextColor?: string
  ) => {
    inputStyleX = shadow ? { ...inputStyleX, ...styles.shadow } : inputStyleX;
    return (
      <Item
        stackedLabel={label !== undefined}
        style={
          style !== undefined
            ? { ...styles.itemStyle, ...(style as object) }
            : styles.itemStyle
        }
      >
        {label && (
          <Label
            {...labelProps}
            style={
              labelProps?.style
                ? { ...labelStyle, ...(labelProps.style as object) }
                : labelStyle
            }
          >
            {label}
          </Label>
        )}

        <TextareaX
          {...propsX}
          placeholder={
            translateText
              ? translateText(propsX?.placeholder as string)
              : propsX.placeholder
          }
          placeholderTextColor={placeholderTextColor ?? '#C4C4C4'}
          style={
            TextareaStyle ? { ...inputStyleX, ...TextareaStyle } : inputStyleX
          }
        />
      </Item>
    );
  };
  switch (type) {
    case 'material':
      return renderElement(styles.material, styles.textMaterial);
    case 'material-black':
      return renderElement(styles.materialBlack, {
        ...styles.textMaterial,
        color: 'black',
      });
    case 'bordered':
      return renderElement(
        styles.bordered,
        {
          ...styles.textDefault,
          color: '#979797',
          marginLeft: 10,
          fontWeight: 'bold',
        },
        borderedInputVariables.placeholderColor
      );
    default:
      return renderElement(
        styles.default,
        styles.textDefault,
        primaryInputVariables.placeholderColor
      );
  }
};
