import React, { FC } from 'react';
import { styles } from './styles';
import { Icon, Item, NativeBase, Picker, RnViewStyleProp } from 'native-base';
import * as ReactNative from 'react-native';
import { View, Platform } from 'react-native';
import {
  borderedInputVariables,
  primaryInputVariables,
} from '../../Configurations/ThemeConfig';
import { Label } from '../Label/Label';
import useLanguage from '../../services/LanguageService';

export type SelectProps = NativeBase.Picker & {
  type?:
    | 'material'
    | 'custom'
    | 'bordered'
    | 'material-black'
    | 'material-gray';
  pickerProps?: ReactNative.PickerItemProps;
  pickerList: [{ value: string; label: string; color?: string }];
  selectStyle?: any;
  labelProps?: NativeBase.Label;
  selectProps?: NativeBase.Input;
  label?: string;
  style?: RnViewStyleProp;
  validationInfo?: string[];
  shadow?: boolean;
};
export const Select: FC<SelectProps> = (props: SelectProps) => {
  const {
    selectStyle,
    label,
    style,
    labelProps,
    type,
    pickerList,
    pickerProps,
    shadow,
  } = props;
  const propsX = props;
  delete propsX.style;
  const translateText = useLanguage().translateText;
  const renderElement = (
    selectStyleX?: any,
    labelStyle?: any,
    placeholderTextColor?: string
  ) => {
    selectStyleX = shadow
      ? { ...selectStyleX, ...styles.shadow }
      : selectStyleX;
    return (
      <Item
        stackedLabel={label !== undefined}
        style={
          style !== undefined
            ? { ...styles.itemStyle, ...(style as object) }
            : styles.itemStyle
        }
      >
        {label && (
          <Label
            {...labelProps}
            style={
              labelProps?.style
                ? { ...labelStyle, ...(labelProps.style as object) }
                : labelStyle
            }
          >
            {label}
          </Label>
        )}
        <View style={selectStyleX}>
          <Picker
            placeholder={
              translateText
                ? translateText(propsX?.placeholder as string)
                : propsX.placeholder
            }
            iosIcon={
              <Icon
                style={{
                  alignSelf: 'center',
                  color: placeholderTextColor ?? '#C4C4C4',
                }}
                name="arrow-down"
              />
            }
            placeholderStyle={{
              color: placeholderTextColor ?? '#C4C4C4',
              fontSize: 16,
              lineHeight: 18,
            }}
            itemTextStyle={{ color: '#4a4a4a' }}
            itemStyle={{ fontSize: 14 }}
            textStyle={{ color: '#4a4a4a' }}
            mode="dialog"
            {...propsX}
            style={[selectStyle]}
          >
            {pickerList
              .filter((val) => !(Platform.OS === 'ios' && val.value === ''))
              .map((item, index) => {
                return (
                  <Picker.Item
                    key={index}
                    label={item.label}
                    value={item.value}
                    color={item.color ?? '#4a4a4a'}
                    {...pickerProps}
                  />
                );
              })}
          </Picker>
        </View>
      </Item>
    );
  };
  switch (type) {
    case 'material':
      return renderElement(styles.material, styles.textMaterial);
    case 'bordered':
      return renderElement(
        styles.bordered,
        {
          ...styles.textDefault,
          color: borderedInputVariables.labelColor,
          marginLeft: 10,
          fontWeight: 'bold',
        },
        borderedInputVariables.placeholderColor
      );
    case 'material-black':
      return renderElement(
        [styles.material, { color: 'black', borderColor: 'black' }],
        {
          ...styles.textDefault,
          color: 'black',
        }
      );
    case 'material-gray':
      return renderElement(styles.materialGray, {
        ...styles.textDefault,
        color: '#979797',
        // borderColor: '#979797'
      });
    default:
      return renderElement(
        styles.default,
        styles.textDefault,
        primaryInputVariables.placeholderColor
      );
  }
};
