import React, { FC } from 'react';
import { RnTextStyleProp, RnViewStyleProp } from 'native-base';
import { ButtonColors } from '../../Configurations/ThemeConfig';
import { View } from 'react-native';
import { Text } from '../Text/Text';

type TagProps = {
  title: string;
  themeColor?: string;
  fontColor?: string;
  styles?: RnViewStyleProp;
  textStyles?: RnTextStyleProp;
  width?: number | string;
  height?: number | string;
  lines?: number;
};
export const Tag: FC<TagProps> = (props: TagProps) => {
  const {
    title,
    themeColor,
    fontColor,
    styles,
    width,
    height,
    textStyles,
    lines
  } = props;
  return (
    <View
      style={[
        {
          backgroundColor: themeColor ?? ButtonColors.primary,
          alignSelf: 'flex-start',
          paddingVertical: 8,
          paddingRight: 7,
          paddingLeft: 10,
          margin: 5,
          borderRadius: 5,
          width: width ?? 'auto',
          height: height ?? 'auto',
        },
        styles,
      ]}
    >
      <Text
        numberOfLines={lines}
        style={[
          {
            fontWeight: 'bold',
            fontSize: 14,
            lineHeight: 15,
            textAlign: 'left',
            color: fontColor ?? 'white',
          },
          textStyles,
        ]}
      >
        {title}
      </Text>
    </View>
  );
};
